/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Community System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets;

import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;
import com.silverwrist.venice.core.*;
import com.silverwrist.venice.servlets.format.*;

public class SIGFrontEnd extends VeniceServlet
{
  public String getServletInfo()
  {
    String rc = "SIGFrontEnd servlet - Redirects to the \"default feature\" of a SIG\n"
              + "Part of the Venice Web conferencing system\n";
    return rc;

  } // end getServletInfo

  public void doGet(HttpServletRequest request, HttpServletResponse response)
    throws ServletException, IOException
  {
    UserContext user = getUserContext(request);
    RenderData rdat = createRenderData(request,response);
    String page_title = null;
    ContentRender content = null;

    try
    { // get the SIG alias name from the request path info
      String sigalias = request.getPathInfo().substring(1);

      // get the SIG's context from the alias name
      SIGContext sig = user.getSIGContext(sigalias);

      // get the default servlet from the SIG context
      String def_applet = sig.getDefaultApplet();
      if (def_applet==null)
	throw new DataException("unable to get SIG default servlet");

      // redirect to the appropriate top-level page!
      String url = response.encodeRedirectURL(rdat.getFullServletPath(def_applet));
      response.sendRedirect(url);
      return;

    } // end try
    catch (DataException de)
    { // set up to display an ErrorBox
      page_title = "Database Error";
      content = new ErrorBox(page_title,"Database error finding SIG: " + de.getMessage(),"top");

    } // end catch

    changeMenuTop(request);

    // this code is only used if we have to display an ErrorBox
    BaseJSPData basedat = new BaseJSPData(page_title,"sig" + request.getPathInfo(),content);
    basedat.transfer(getServletContext(),rdat);

  } // end doGet

} // end class SIGFrontEnd
