/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Community System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets;

import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;
import com.silverwrist.venice.core.*;
import com.silverwrist.venice.servlets.format.*;

public class SIGProfile extends VeniceServlet
{
  public String getServletInfo()
  {
    String rc = "SIGProfile servlet - Displays the profile of a SIG\n"
              + "Part of the Venice Web Communities System\n";
    return rc;

  } // end getServletInfo

  public void doGet(HttpServletRequest request, HttpServletResponse response)
    throws ServletException, IOException
  {
    UserContext user = getUserContext(request);
    RenderData rdat = createRenderData(request,response);
    String page_title = null;
    Object content = null;

    try
    { // get the ID of the SIG we want to see the profile of
      int sigid = Integer.parseInt(request.getParameter("sig"));

      // get the SIG context for the user
      SIGContext sig = user.getSIGContext(sigid);

      // create the profile display
      content = new SIGProfileData(getVeniceEngine(),user,sig);
      page_title = "SIG Profile: " + sig.getName();
      changeMenuSIG(request,sig);

    } // end try
    catch (NumberFormatException nfe)
    { // something as simple as an improper SIGID brought us down?!?!?
      page_title = "Input Error";
      content = new ErrorBox(page_title,"SIG ID not valid: " + request.getParameter("sig"),"top");

    } // end catch
    catch (DataException de)
    { // in this case, we had database trouble
      page_title = "Database Error";
      content = new ErrorBox(page_title,"Database error accessing SIG: " + de.getMessage(),"top");

    } // end catch

    BaseJSPData basedat = new BaseJSPData(page_title,"sigprofile?" + request.getQueryString(),content);
    basedat.transfer(getServletContext(),rdat);

  } // end doGet

} // end class SIGProfile
