/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Community System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets;

import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;
import org.apache.log4j.*;
import org.apache.log4j.xml.DOMConfigurator;
import com.silverwrist.venice.core.*;
import com.silverwrist.venice.servlets.format.*;

public class Top extends VeniceServlet
{
  public void init(ServletConfig config) throws ServletException
  {
    super.init(config);  // required before we do anything else
    ServletContext ctxt = config.getServletContext();

    // Initialize LOG4J logging.
    DOMConfigurator.configure(ctxt.getInitParameter("logging.config"));

    // Initialize the Venice engine.
    VeniceEngine engine = getVeniceEngine(ctxt);

    // Initialize the Venice rendering system.
    RenderConfig.getRenderConfig(ctxt);

  } // end init

  public void destroy()
  {
    super.destroy();

  } // end destroy

  public String getServletInfo()
  {
    String rc = "Top applet - Displays the Venice front page\n"
              + "Part of the Venice Web conferencing system\n";
    return rc;

  } // end getServletInfo

  public void doGet(HttpServletRequest request, HttpServletResponse response)
    throws ServletException, IOException
  {
    UserContext user = getUserContext(request);
    RenderData rdat = createRenderData(request,response);
    ContentRender content = null;
    String page_title = "My Front Page";

    try
    { // attempt to get the user content
      content = new TopContent(user);

    } // end try
    catch (DataException e)
    { // there was a database error, whoops!
      page_title = "Database Error";
      content = new ErrorBox(page_title,"Error loading front page: " + e.getMessage(),null);

    } // end catch

    changeMenuTop(request);

    BaseJSPData basedat = new BaseJSPData(page_title,"top",content);
    basedat.transfer(getServletContext(),rdat);

  } // end doGet

} // end class Top
