/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Community System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets;

import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;
import com.silverwrist.venice.core.*;
import com.silverwrist.venice.servlets.format.*;

public class UserDisplay extends VeniceServlet
{
  public String getServletInfo()
  {
    String rc = "UserDisplay servlet - Displays Venice user profiles\n"
              + "Part of the Venice Web conferencing system\n";
    return rc;

  } // end getServletInfo

  public void doGet(HttpServletRequest request, HttpServletResponse response)
    throws ServletException, IOException
  {
    UserContext user = getUserContext(request);
    RenderData rdat = createRenderData(request,response);
    String page_title = null;
    Object content = null;

    try
    { // use the request path info to get the username to load the profile from
      String uname = request.getPathInfo().substring(1);
      UserProfile prof = user.getProfile(uname);
      content = new UserProfileData(prof);
      page_title = "User Profile - " + prof.getUserName();

    } // end try
    catch (DataException de)
    { // unable to get the user name
      page_title = "Database Error";
      content = new ErrorBox(page_title,"Database error finding user: " + de.getMessage(),"top");

    } // end catch

    changeMenuTop(request);

    // format and display the user
    BaseJSPData basedat = new BaseJSPData(page_title,"user" + request.getPathInfo(),content);
    basedat.transfer(getServletContext(),rdat);

  } // end doGet

} // end class UserDisplay
