/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Community System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import java.io.Writer;
import java.io.IOException;
import java.util.*;
import com.silverwrist.venice.core.*;

public class TopContent implements ContentRender
{
  // Static constants
  public static final int MAX_COLS = 2;

  // Attributes
  private int actual_cols = MAX_COLS;
  private int[] col_sizes;
  private Vector panels = new Vector();
  private boolean display_configure;

  public TopContent(UserContext uc) throws DataException
  {
    int i; // loop counter

    // get the current view configuration
    FrontPageViewConfig vconfig = uc.getFrontPageViewConfig(MAX_COLS);
    if (vconfig.getNumColumns()<MAX_COLS)
      actual_cols = vconfig.getNumColumns();

    // compute the column sizes in percentages
    col_sizes = new int[actual_cols];
    int base_amt = 100 / actual_cols;
    int rem_amt = 100 % actual_cols;
    for (i=0; i<actual_cols; i++)
    { // initialize the column sizes
      col_sizes[i] = base_amt;
      if (i<rem_amt)
	col_sizes[i]++;

    } // end for

    // load the top content
    TopContentPanel parray[];
    for (i=0; i<vconfig.getNumRows(); i++)
    { // create array and load it with panels
      parray = new TopContentPanel[actual_cols];
      for (int j=0; j<actual_cols; j++)
      { // create and configure the parts in this row
	parray[j] = TopContentPanel.create(vconfig.getPartID(i,j));
	parray[j].configure(uc,vconfig.getParameter(i,j));

      } // end for

      panels.addElement(parray);

    } // end for

    display_configure = uc.isLoggedIn();

  } // end constructor

  public void renderHere(Writer out, RenderData rdat) throws IOException
  {
    out.write("<TABLE BORDER=0 ALIGN=CENTER WIDTH=\"100%\" CELLPADDING=4 CELLSPACING=0>\n");

    Enumeration enum = panels.elements();
    while (enum.hasMoreElements())
    { // output each row in turn
      TopContentPanel[] rowarray = (TopContentPanel[])(enum.nextElement());
      out.write("<TR VALIGN=TOP>\n");

      for (int i=0; i<actual_cols; i++)
      { // write the table data header and then render the content
	out.write("<TD ALIGN=LEFT WIDTH=\"" + String.valueOf(col_sizes[i]) + "%\">\n");
	rowarray[i].renderHere(out,rdat);
	out.write("</TD>\n");

      } // end for

      out.write("</TR>\n");
    
    } // end while

    out.write("</TABLE>\n");

    if (display_configure)
    { // display the Configure button
      out.write("<HR WIDTH=\"80%\"><DIV ALIGN=\"LEFT\">\n<A HREF=\"\"><IMG SRC=\"");
      out.write(rdat.getFullImagePath("bn_configure.gif"));
      out.write("\" ALT=\"Configure\" WIDTH=80 HEIGHT=24 BORDER=0></A>\n</DIV>\n");

    } // end if

    rdat.writeFooter(out);

  } /* end renderHere */

} // end class TopContent
